/******************************************************************************
*
* project name: DISSOLVE
* initial date: 26/06/2000
* authors:      thomas.nussbaumer@gmx.net
*               xdanger1@caramail.com
* description:  graphics data and decompression routine
*
* picture converted and RLE compressed using Image Studio v1.1 (Matt Johnson)
*
*
* -----------------------------------------------------------------------------
* Revision History
* -----------------------------------------------------------------------------
*
* v1.20: 14/02/2002
*        minor adaptions to TIGCC 0.93 [xdanger]
*        picture replaced [tnussb]
*
* v1.00: 26/06/2000
*        initial version
*
*******************************************************************************/

/*===========================================================================*/
/* RLE decompression routine                                                 */
/*                                                                           */
/* dest      ... pointer to destination where store decompressed data        */
/* source    ... pointer to RLE compressed data                              */
/* size      ... size of decompressed data                                   */
/* drawbytes ... number of bytes to draw per line                            */
/* offset    ... number of bytes to skip after each line                     */
/*                                                                           */
/*                                                                           */
/* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! */
/*                                                                           */
/* NOTE: an important optimization hint is to define internal routines which */
/*       are used just once or twice static.                                 */
/*       This enables the optimizer to completely inline them !!!!           */
/*===========================================================================*/
static void Decompress(unsigned char* dest,
                       unsigned char* source,
                       unsigned short size,
                       unsigned char  drawbytes,
                       unsigned char  offset)
{
    unsigned char len,val,counter = 0;

    while (size) {
        if (*source == 0x91) {
            source++;
            val = *source++;
            len = *source++;
            while (len) {
                *dest++ = val;
                len--;
                size--;
                counter++;
                if (counter == drawbytes) {
                    dest+=offset;
                    counter=0;
                }
            }
        }
        else {
           *dest++ = *source++;
           size--;
           counter++;
           if (counter == drawbytes) {
               dest+=offset;
               counter=0;
           }
        }
    }
}


//-----------------------------------------------------------------------------
//data for bitplane 1
//-----------------------------------------------------------------------------
static unsigned char data1[] = {
  0x91,0xFF,0x43,0xF7,0xFF,0xFF,0xC0,0x79,0xC0,0xF0,0x3E,0x07,0x3C,0xFF,0x20,0x0F,0x91,0xFF,0x07,0xE7,
  0xFF,0xFF,0xCF,0x19,0x1E,0x47,0x9C,0xF3,0x3C,0xFE,0x67,0x91,0xFF,0x08,0xEF,0xFF,0xFF,0xCF,0x99,0x3F,
  0x0F,0xC9,0xF9,0x3E,0x7E,0x67,0x91,0xFF,0x0B,0xCF,0xC9,0x3F,0xCF,0xF3,0xFC,0x3E,0x7C,0xE7,0x91,0xFF,
  0x09,0x7F,0xFF,0xCF,0xC9,0x9F,0xE7,0xF3,0xFC,0x3F,0x3C,0xE7,0x91,0xFF,0x08,0x9E,0x7F,0xFF,0xCF,0xC9,
  0xC3,0xF0,0xF3,0xFC,0x3F,0x39,0xE7,0x91,0xFF,0x08,0xB6,0xFF,0xFF,0xCF,0xC9,0xF8,0x7E,0x13,0xFC,0x3F,
  0x93,0xE7,0x91,0xFF,0x08,0x5E,0x7F,0xFF,0xCF,0x99,0xFE,0x7F,0x99,0xF9,0x3F,0x93,0xC0,0x0F,0x91,0xFF,
  0x07,0xDC,0x7F,0xFF,0xCF,0x19,0x9C,0x67,0x1C,0xF3,0x3F,0xC7,0xE7,0x91,0xFF,0x07,0xFE,0xFC,0x7F,0xFF,
  0xC0,0x79,0xC0,0xF0,0x3E,0x07,0x00,0x47,0xE0,0x0F,0x91,0xFF,0x07,0x58,0x3F,0x91,0xFF,0x11,0xFE,0x3C,
  0x3F,0x91,0xFF,0x12,0x78,0x7F,0x91,0xFF,0x11,0xFE,0xE8,0x7F,0x91,0xFF,0x12,0xE8,0x7F,0x91,0xFF,0x12,
  0xA8,0x3F,0xFF,0xFE,0x91,0x00,0x04,0x1C,0x00,0x03,0x91,0xFF,0x09,0x98,0x7F,0xFF,0xFE,0x7F,0x3F,0x9F,
  0xCF,0xF8,0xE3,0x3F,0x91,0xFF,0x09,0x20,0x7F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,0xF3,0xFF,0x3F,0x91,0xFF,
  0x08,0xFE,0x30,0x7F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,0xE7,0xFF,0x3F,0x91,0xFF,0x08,0xF9,0x20,0x7F,0xFF,
  0xFE,0x7F,0x3F,0x9F,0xCF,0xE7,0xFF,0x3F,0x91,0xFF,0x08,0xFC,0x60,0x7F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,
  0xE7,0xFF,0x3F,0x91,0xFF,0x08,0xF2,0x40,0x7F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,0xE7,0xFF,0x3F,0x91,0xFF,
  0x07,0xFE,0x7F,0xDC,0x3F,0xFF,0xFC,0x91,0x00,0x04,0x13,0xFF,0x3F,0x91,0xFF,0x08,0xDF,0xF8,0xBF,0xFF,
  0xFE,0x7F,0x3F,0x9F,0xCF,0xF8,0xF3,0x3F,0x91,0xFF,0x08,0xBF,0xFE,0x7F,0xFF,0xFE,0x00,0x3F,0x9F,0xC0,
  0x1C,0x07,0x3F,0x91,0xFF,0x08,0x9F,0x91,0xFF,0x13,0x3F,0x91,0xFF,0x15,0x7F,0x91,0xFF,0x11,0xBF,0xFF,
  0xBF,0x91,0xFF,0x10,0xFE,0x1F,0x9C,0x7F,0x91,0xFF,0x11,0x1F,0xFD,0x91,0xFF,0x12,0x1F,0xFD,0x91,0xFF,
  0x12,0x0C,0xDF,0x91,0xFF,0x11,0xFE,0x91,0x91,0x01,0xFD,0x91,0xFF,0x12,0x98,0xFD,0x91,0xFF,0x12,0x8D,
  0xCC,0x91,0xFF,0x12,0x8F,0xDB,0x91,0xFF,0x12,0x8F,0x87,0x91,0xFF,0x12,0x0A,0xFD,0x91,0xFF,0x12,0xC1,
  0x91,0xFF,0x13,0xA0,0x37,0x91,0xFF,0x12,0xF8,0x07,0x91,0xFF,0x12,0xDD,0x03,0x91,0xFF,0x12,0xE6,0x7B,
  0x91,0xFF,0x12,0xF6,0x1B,0x91,0xFF,0x12,0xF2,0x03,0x91,0xFF,0x12,0x82,0x03,0x91,0xFF,0x12,0xC0,0x03,
  0x91,0xFF,0x12,0x80,0x03,0x91,0xFF,0x12,0xE2,0x01,0x91,0xFF,0x12,0xDE,0x01,0x91,0xFF,0x12,0xDC,0x03,
  0x91,0xFF,0x12,0xC4,0x03,0x91,0xFF,0x12,0xF8,0x03,0x91,0xFF,0x12,0xC0,0x07,0x91,0xFF,0x11,0xFA,0x00,
  0x03,0x91,0xFF,0x11,0xF7,0xE0,0x0F,0x91,0xFF,0x11,0xF8,0xE0,0x0F,0x91,0xFF,0x11,0xFA,0x80,0x1F,0x91,
  0xFF,0x11,0xFE,0x98,0x07,0x91,0xFF,0x11,0xFE,0xB8,0x1F,0x91,0xFF,0x11,0xEE,0x06,0x3F,0x91,0xFF,0x11,
  0xDE,0xCC,0x0F,0x91,0xFF,0x11,0xCE,0xCC,0x3F,0x91,0xFF,0x11,0xF7,0xC3,0x3F,0x91,0xFF,0x11,0xFE,0x23,
  0x3F,0x91,0xFF,0x11,0xEF,0x1E,0x1F,0x91,0xFF,0x11,0xFE,0xFF,0x7F,0x91,0xFF,0x12,0x3F,0x7F,0x91,0xFF,
  0x12,0x76,0x7F,0x91,0xFF,0x0F,0x0F,0xFC,0x1F,0xA6,0x7F,0x91,0xFF,0x0F,0x1F,0xFD,0x9F,0xA6,0x3F,0x91,
  0xFF,0x0F,0x1F,0xFC,0x3F,0x9E,0x7F,0x91,0xFF,0x0F,0x9F,0xFF,0xFF,0xC4,0x7F,0xFF,0x3F,0xFB,0xE7,0xF6,
  0x91,0xFF,0x03,0xBE,0x91,0xFF,0x09,0xC0,0xFF,0x91,0xFE,0x03,0x73,0xFD,0x9F,0xFF,0xFF,0xE7,0x91,0xFF,
  0x08,0xFD,0xF0,0xFF,0xFE,0xEB,0x7E,0xF7,0xEF,0xA7,0x7B,0xDF,0xEF,0xBF,0x91,0xFF,0x07,0xFD,0xF0,0x7F,
  0xFF,0xFB,0x7F,0xE7,0x9F,0x37,0xFE,0xF7,0xFF,0x9F,0x2D,0x3F,0x91,0xFF,0x05,0xF7,0xF0,0x91,0xFF,0x03,
  0x91,0x7F,0x03,0xA5,0x1F,0xFF,0xF7,0x17,0x4C,0xDF,0x91,0xFF,0x05,0x88,0x71,0xFF,0xFD,0xBE,0xFE,0xFF,
  0xFF,0xFE,0xFF,0xFF,0xEE,0xFB,0x6D,0xBF,0x91,0xFF,0x05,0x38,0x71,0xFF,0xFD,0x9E,0xFE,0xEF,0x9D,0x7F,
  0x89,0x4F,0xEE,0x57,0xFF,0xBF,0x91,0xFF,0x04,0xFE,0x78,0x79,0xFF,0xFF,0xB5,0xFD,0xFF,0xDD,0xFF,0xED,
  0x6F,0xDE,0xFF,0x7D,0x7F,0x91,0xFF,0x04,0xFE,0x78,0x7C,0xFF,0xFF,0xFB,0x91,0xFF,0x0E,0xFC,0x7C,0x7C,
  0x7F,0x91,0xFF,0x10,0xFC,0xFA,0xFE,0x7F,0x91,0xFF,0x10,0xFC,0x70,0xFE,0x7F,0x91,0xFF,0x10,0xFC,0x94,
  0xF7,0x3F,0x91,0xFF,0x03,0xFD,0xF5,0xFA,0xBE,0xF7,0xD7,0x91,0xFF,0x07,0xFE,0xBD,0xF7,0x3F,0x91,0xFF,
  0x03,0xFE,0x67,0xEC,0xF9,0xF1,0x9F,0x91,0xFF,0x07,0xFE,0x3F,0xFF,0xDF,0x91,0xFF,0x03,0xFB,0xFF,0xFF,
  0xFB,0x7D,0x91,0xFF,0x09,0x3F,0xFF,0x8F,0x91,0xFF,0x04,0xFD,0xEF,0xB7,0x4D,0xF7,0x91,0xFF,0x08,0xBE,
  0xDF,0xAF,0x91,0xFF,0x03,0xF3,0x73,0xFE,0x6F,0xDD,0xCF,0x91,0xFF,0x08,0x8E,0xFF,0xDF,0x91,0xFF,0x03,
  0xF6,0x7F,0xFF,0xFF,0x5F,0x91,0xFF,0x09,0x0F,0x7F,0x91,0xFF,0x04,0xF3,0x7F,0x7F,0xE5,0xDB,0x91,0xFF,
  0x09,0x89,0x91,0xFF,0x05,0xFE,0xFD,0x7F,0xBF,0xDF,0xF7,0x91,0xFF,0x08,0xE3,0x91,0xFF,0x07,0x7F,0x91,
  0xFF,0x42};



//-----------------------------------------------------------------------------
//data for bitplane 2
//-----------------------------------------------------------------------------
static unsigned char data2[] = {
  0x91,0xFF,0x46,0xC0,0x79,0xC0,0xF0,0x3E,0x07,0x3C,0xFF,0x20,0x0F,0x91,0xFF,0x0A,0xCF,0x19,0x1E,0x47,
  0x9C,0xF3,0x3C,0xFE,0x67,0x91,0xFF,0x08,0xF7,0xFF,0xFF,0xCF,0x99,0x3F,0x0F,0xC9,0xF9,0x3E,0x7E,0x67,
  0x91,0xFF,0x08,0xE7,0xBF,0xFF,0xCF,0xC9,0x3F,0xCF,0xF3,0xFC,0x3E,0x7C,0xE7,0x91,0xFF,0x08,0xE6,0xFF,
  0xFF,0xCF,0xC9,0x9F,0xE7,0xF3,0xFC,0x3F,0x3C,0xE7,0x91,0xFF,0x08,0xE6,0xFF,0xFF,0xCF,0xC9,0xC3,0xF0,
  0xF3,0xFC,0x3F,0x39,0xE7,0x91,0xFF,0x08,0xCE,0x7F,0xFF,0xCF,0xC9,0xF8,0x7E,0x13,0xFC,0x3F,0x93,0xE7,
  0x91,0xFF,0x08,0xAC,0x7F,0xFF,0xCF,0x99,0xFE,0x7F,0x99,0xF9,0x3F,0x93,0xC0,0x0F,0x91,0xFF,0x07,0x2C,
  0x7F,0xFF,0xCF,0x19,0x9C,0x67,0x1C,0xF3,0x3F,0xC7,0xE7,0x91,0xFF,0x08,0x5C,0x7F,0xFF,0xC0,0x79,0xC0,
  0xF0,0x3E,0x07,0x00,0x47,0xE0,0x0F,0x91,0xFF,0x07,0xFC,0x7F,0x91,0xFF,0x12,0xF8,0x7F,0x91,0xFF,0x12,
  0xF8,0x3F,0x91,0xFF,0x12,0xF8,0x3F,0x91,0xFF,0x12,0xD8,0x3F,0x91,0xFF,0x12,0xD0,0x3F,0xFF,0xFE,0x91,
  0x00,0x04,0x1C,0x00,0x03,0x91,0xFF,0x09,0xB0,0x3F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,0xF8,0xE3,0x3F,0x91,
  0xFF,0x09,0x10,0x3F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,0xF3,0xFF,0x3F,0x91,0xFF,0x08,0xFD,0x00,0x3F,0xFF,
  0xFE,0x7F,0x3F,0x9F,0xCF,0xE7,0xFF,0x3F,0x91,0xFF,0x08,0xFC,0x00,0x3F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,
  0xE7,0xFF,0x3F,0x91,0xFF,0x08,0x78,0x00,0x3F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,0xE7,0xFF,0x3F,0x91,0xFF,
  0x08,0x78,0x40,0x3F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,0xE7,0xFF,0x3F,0x91,0xFF,0x08,0xFB,0xC0,0x3F,0xFF,
  0xFC,0x91,0x00,0x04,0x13,0xFF,0x3F,0x91,0xFF,0x0A,0x3F,0xFF,0xFE,0x7F,0x3F,0x9F,0xCF,0xF8,0xF3,0x3F,
  0x91,0xFF,0x08,0xDF,0xFF,0xBF,0xFF,0xFE,0x00,0x3F,0x9F,0xC0,0x1C,0x07,0x3F,0x91,0xFF,0x08,0xBF,0x91,
  0xFF,0x13,0x1F,0x91,0xFF,0x13,0x1F,0x91,0xFF,0x13,0x1F,0x91,0xFF,0x13,0x1F,0xEF,0x91,0xFF,0x11,0xFE,
  0x1F,0xF6,0x7F,0x91,0xFF,0x10,0xFE,0x1F,0xFA,0x7F,0x91,0xFF,0x10,0xFE,0x1B,0xFE,0x7F,0x91,0xFF,0x11,
  0x0F,0xFE,0x91,0xFF,0x12,0x0F,0xFE,0x91,0xFF,0x12,0x0E,0x3F,0x91,0xFF,0x12,0x0E,0x05,0x91,0xFF,0x12,
  0x0E,0x01,0x91,0xFF,0x12,0x85,0x01,0x91,0xFF,0x12,0x80,0x01,0x91,0xFF,0x12,0xC0,0x01,0x91,0xFF,0x12,
  0xC0,0x01,0x91,0xFF,0x12,0xE0,0x01,0x91,0xFF,0x12,0xC0,0x01,0x91,0xFF,0x12,0xC0,0x01,0x91,0xFF,0x12,
  0xC0,0x01,0x91,0xFF,0x12,0xC0,0x01,0x91,0xFF,0x12,0x80,0x01,0x91,0xFF,0x12,0xC0,0x01,0x91,0xFF,0x12,
  0xC0,0x03,0x91,0xFF,0x12,0xE0,0x03,0x91,0xFF,0x12,0xE0,0x03,0x91,0xFF,0x12,0xF8,0x03,0x91,0xFF,0x12,
  0xF0,0x03,0x91,0xFF,0x12,0x60,0x03,0x91,0xFF,0x11,0xFC,0x40,0x07,0x91,0xFF,0x11,0xF8,0x40,0x07,0x91,
  0xFF,0x12,0x40,0x07,0x91,0xFF,0x12,0x60,0x07,0x91,0xFF,0x12,0x60,0x0F,0x91,0xFF,0x12,0x60,0x0F,0x91,
  0xFF,0x12,0xF8,0x0F,0x91,0xFF,0x12,0x32,0x1F,0x91,0xFF,0x12,0x32,0x1F,0x91,0xFF,0x11,0xCE,0x3C,0x1F,
  0x91,0xFF,0x11,0xC0,0x1C,0x1F,0x91,0xFF,0x11,0xF0,0x09,0x3F,0x91,0xFF,0x12,0x00,0x3F,0x91,0xFF,0x11,
  0xFE,0x40,0x3F,0x91,0xFF,0x12,0x08,0x3F,0x91,0xFF,0x12,0x38,0x3F,0x91,0xFF,0x10,0xFE,0x1F,0x98,0x7F,
  0x91,0xFF,0x12,0xC0,0x7F,0x91,0xFF,0x12,0xC0,0x7F,0xFF,0xFE,0xFC,0x1F,0xF9,0x9F,0xFF,0xFF,0xC1,0x91,
  0xFF,0x09,0xE0,0x7F,0xFF,0x7F,0x7F,0x77,0xE6,0xBF,0xFF,0xFF,0xF7,0x91,0xFF,0x09,0xE0,0x7F,0xFE,0xF7,
  0x7F,0x77,0xDF,0xBF,0xBD,0xEF,0xF7,0xDE,0x6D,0xBF,0x91,0xFF,0x05,0xFE,0xF0,0xFF,0xFC,0xCF,0x7E,0x77,
  0xDF,0x86,0x13,0x9F,0xE7,0x49,0x60,0x1F,0x91,0xFF,0x05,0xF8,0xF0,0xFF,0xFD,0x9F,0x7E,0xE4,0x9F,0x16,
  0xB3,0x9F,0xEE,0xDB,0x64,0xBF,0x91,0xFF,0x05,0xF0,0x70,0xFF,0xFD,0xBF,0x7E,0xE7,0x9F,0x24,0x79,0xCF,
  0xEE,0x36,0x4D,0xBF,0x91,0xFF,0x05,0xC0,0x78,0xFF,0xFD,0xB6,0xFE,0xEF,0xDF,0x64,0xFD,0xEF,0xEE,0xF0,
  0x49,0xBF,0x91,0xFF,0x05,0x80,0x38,0xFF,0xFD,0xCE,0xFE,0xEF,0xE3,0x6E,0x33,0x9F,0xEF,0x12,0xDB,0xBF,
  0x91,0xFF,0x05,0x80,0x38,0xFF,0xFE,0xFD,0x91,0xFF,0x0F,0x80,0x1C,0x91,0xFF,0x12,0x00,0x1C,0x7F,0x91,
  0xFF,0x11,0x80,0x0E,0x3F,0x91,0xFF,0x11,0x60,0x0E,0x3F,0x91,0xFF,0x03,0xFE,0xFB,0xF7,0x7D,0xFB,0xEF,
  0x91,0xFF,0x08,0x40,0x0F,0x1F,0x91,0xFF,0x03,0xF9,0x7C,0xF7,0x9A,0x6D,0xF3,0x91,0xFF,0x08,0xC0,0x0F,
  0x9F,0x91,0xFF,0x03,0xFB,0x3C,0xEF,0x97,0x4D,0xF3,0x91,0xFF,0x08,0xC0,0x1F,0x9F,0x91,0xFF,0x03,0xF3,
  0x3D,0xDF,0xB7,0x5D,0xF7,0x91,0xFF,0x08,0xC0,0x3F,0xDF,0x91,0xFF,0x03,0xF7,0x7B,0xDF,0x76,0x5D,0xEF,
  0x91,0xFF,0x08,0xF0,0x3F,0xEF,0x91,0xFF,0x03,0xF7,0x67,0xBC,0xE6,0xD9,0x9F,0x91,0xFF,0x08,0xF0,0x7F,
  0x91,0xFF,0x04,0xF6,0xCF,0xB9,0xF6,0xDB,0x3F,0x91,0xFF,0x08,0xF6,0x91,0xFF,0x05,0xF9,0xC3,0x78,0x71,
  0xE7,0x0F,0x91,0xFF,0x08,0xFD,0x91,0xFF,0x06,0xFE,0x91,0xFF,0x43};
